Name:	draco
Version:	1.5.7
Release:	 %mkrel 1
Summary:	A library for compressing and decompressing 3D geometric meshes and point clouds
License:	Apache-2.0
Group:     Sciences/Geosciences
URL:		https://github.com/google/%{name}
Source0:	 %{name}-%{version}.tar.xz
Patch0:		0001-Use-system-gtest.patch
BuildRequires:	cmake
BuildRequires:	lib64gtest-devel
BuildRequires:	libstdc++-devel
BuildRequires:	pkgconfig(python3)

%description
Draco is a library for compressing and decompressing 3D geometric
meshes and point clouds. It is intended to improve the storage and
transmission of 3D graphics.
Draco was designed and built for compression efficiency and speed. The
code supports compressing points, connectivity information, texture
coordinates, color information, normals, and any other generic
attributes associated with geometry. With Draco, applications using 3D
graphics can be significantly smaller without compromising visual
fidelity. For users, this means apps can now be downloaded faster, 3D
graphics in the browser can load quicker, and VR and AR scenes can now
be transmitted with a fraction of the bandwidth and rendered quickly.
Draco is released as C++ source code that can be used to compress 3D
graphics as well as C++ and Javascript decoders for the encoded data.

%package	devel
Summary: Development files for draco
Group:      Development/Libraries
Requires: %{name} = %{version}-%{release}

%description	devel
%{summary}.

%package	static
Summary: Static files for draco
Requires: %{name}-devel = %{version}-%{release}

%description	static
%{summary}.

%prep
%autosetup -p1 -n %{name}-%{version}

# Remove precompiled CSS and Javascript along binaries
rm -fr {javascript,maya,docs/assets}

%build
%cmake \
    -DBUILD_SHARED_LIBS=ON \
    -DCMAKE_BUILD_TYPE=Release
%cmake_build


%install
%cmake_install

# Create missing man files downstream
mkdir -p %{buildroot}%{_mandir}/man1
LD_LIBRARY_PATH=%{buildroot}%{_libdir} help2man -N --version-string=%{version} \
	-o %{buildroot}%{_mandir}/man1/%{name}_decoder-%{version}.1 \
	%{buildroot}%{_bindir}/%{name}_decoder
LD_LIBRARY_PATH=%{buildroot}%{_libdir} help2man -N --version-string=%{version} \
	-o %{buildroot}%{_mandir}/man1/%{name}_encoder-%{version}.1 \
	%{buildroot}%{_bindir}/%{name}_encoder

%files
%doc README.md LICENSE AUTHORS
%{_bindir}/%{name}_decoder
%{_bindir}/%{name}_decoder-%{version}
%{_bindir}/%{name}_encoder
%{_bindir}/%{name}_encoder-%{version}
%{_libdir}/lib%{name}.so.9
%{_libdir}/lib%{name}.so.9.0.0
%{_mandir}/man1/%{name}_decoder-%{version}.1*
%{_mandir}/man1/%{name}_encoder-%{version}.1*

%files devel
%{_includedir}/%{name}/
%{_datadir}/cmake/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%files static
%{_libdir}/lib%{name}.a

%changelog
* Tue Mar 05 2024 pp - 1.5.7-1pclos2024
- new version

* Sat Oct 28 2023 pp - 1.5.6-1pclos2023
- import package

